@@ -33,12 +33,17 @@ from pybi.utils.data_gen import (
     random_dv_name,
     get_project_root,
 )
-import pybi as pbi
-from pybi.core.sql import SqlExtractor, SqlInfo, SqlWrapper
+
+from pybi.core.sql import SqlInfo, SqlWrapper
 import pybi.utils.sql as sqlUtils
 from pybi.easyEcharts.base import BaseChart, ChartCollector
 from pybi.easyEcharts import easy_echarts
-from pybi.core.components.reactiveComponent.echarts import EChartInfo, EChartDatasetInfo
+from pybi.core.components.reactiveComponent.echarts import (
+    EChartInfo,
+    EChartDatasetInfo,
+    EChartJscode,
+    OptionsExtractor,
+)
 
 if TYPE_CHECKING:
     pass
@@ -254,23 +259,39 @@ class App(ContainerComponent):
                     chart._create_default_click_filter()
 
             for chart in options._collector:
-                opts, updateInfos = chart.get_options_infos()
+                options, updateInfos = chart.get_options_infos()
+
+                ds_infos = []
+                jscodes = []
+
+                OptionsExtractor.extract_and_remove_from_dict(
+                    options, ds_infos, jscodes
+                )
+
                 ds_infos = [
-                    EChartDatasetInfo({}, path, sql._sql_info)
-                    for path, sql in SqlExtractor.extract_from_dict(opts)
+                    EChartDatasetInfo({}, path, sql._sql_info) for path, sql in ds_infos
                 ]
-                info = EChartInfo(opts, ds_infos, updateInfos)
+
+                jscodes = [EChartJscode(path, jscode) for path, jscode in jscodes]
+
+                info = EChartInfo(options, ds_infos, updateInfos, jscodes)
                 cp._add_chart_info(info)
 
         else:
             cp = EChart(option_type="dict")
 
+            ds_infos = []
+            jscodes = []
+
+            OptionsExtractor.extract_and_remove_from_dict(options, ds_infos, jscodes)
+
             ds_infos = [
-                EChartDatasetInfo({}, path, sql._sql_info)
-                for path, sql in SqlExtractor.extract_from_dict(options)
+                EChartDatasetInfo({}, path, sql._sql_info) for path, sql in ds_infos
             ]
 
-            info = EChartInfo(options, ds_infos, [])
+            jscodes = [EChartJscode(path, jscode) for path, jscode in jscodes]
+
+            info = EChartInfo(options, ds_infos, [], jscodes)
             cp._add_chart_info(info)
 
         host = host or self._get_temp_host() or self
