@@ -175,13 +175,22 @@ class TabsComponent(ContainerComponent):
         mode: 'fullWidth' | 'narrowing'
         """
         super().__init__(ComponentTag.Tabs, appHost)
+        if len(names) > len(set(names)):
+            raise Exception("names cannot be duplicated")
         self.names = names
         self.mode = mode
 
+        self.__name2idx = {name: idx for idx, name in enumerate(self.names)}
+
         for _ in range(len(self.names)):
             self._add_children(BoxComponent(appHost))
 
-    def __getitem__(self, idx: int):
+    def __getitem__(self, idx: Union[int, str]):
+        if isinstance(idx, str):
+            if idx not in self.__name2idx:
+                raise Exception(f"tab name[{idx}] not found")
+            idx = self.__name2idx[idx]
+
         res = self.children[idx]
         assert isinstance(res, ContainerComponent)
         return res
