@@ -4,7 +4,7 @@ import pandas as pd
 from enum import Enum
 from typing import Dict, List, Any, Callable, Optional, TYPE_CHECKING, Union
 
-from pybi.core.sql import Sql
+from pybi.core.sql import SqlInfo
 
 if TYPE_CHECKING:
     from pybi.app import App
@@ -33,13 +33,13 @@ class DataViewBase(Jsonable):
 
 
 class DataView(DataViewBase):
-    def __init__(self, name: str, sql: Sql) -> None:
+    def __init__(self, name: str, sql: str) -> None:
         super().__init__(name, DataViewType.Sql)
         self._sql = sql
 
     def _to_json_dict(self):
         data = super()._to_json_dict()
-        data["sql"] = self._sql.sql
+        data["sql"] = self._sql
         return data
 
 
@@ -102,7 +102,7 @@ class DataSourceField(DataSourceView):
         return f"`{self.name}`"
 
     def __str__(self) -> str:
-        return str(Sql(self._to_sql()))
+        return str(SqlInfo(self._to_sql()))
 
     def _to_sql(self):
         return f"select {self._get_sql_field_name()} from {self.source_name}"
