@@ -47,14 +47,16 @@ class PieChart(BaseChart):
     def get_options_infos(self):
         opts = super().get_options()
 
-        update_config, update_axis, remove_series = merge_user_options(opts)
-
-        agg_field = sqlUtils.apply_agg(self.agg, self.value)
-        opt_data = pbi.set_dataView(
-            f"select `{self.name}`,{agg_field} from {self.data} group by `{self.name}`"
-        )
+        base_opt = {
+            "xAxis": None,
+            "yAxis": None,
+            "series": [],
+        }
+        base_opt.update(opts)
 
         series_config = {
+            "id": self.name,
+            "universalTransition": {"enabled": True, "divideShape": "clone"},
             "type": "pie",
             "radius": "50%",
             "emphasis": {
@@ -65,17 +67,17 @@ class PieChart(BaseChart):
                 }
             },
         }
-        update_config(series_config)
-
         series_config.update(self._series_configs)
 
-        ds_info = EChartDatasetInfo(series_config, "dataset[0]", opt_data.source_name)
+        agg_field = sqlUtils.apply_agg(self.agg, self.value)
+        sql = pbi.sql(
+            f"select `{self.name}` as name ,{agg_field} as value,`{self.name}` as groupId from {self.data} group by `{self.name}`"
+        )
 
-        opts["xAxis"] = None
+        series_config["data"] = sql
 
-        opts["yAxis"] = None
+        base_opt["series"].append(series_config)
 
         opts["tooltip"] = {"trigger": "item"}
 
-        remove_series()
-        return opts, [ds_info], self._updateInfos
+        return base_opt, self._updateInfos
